----------------------------------------------------------------------------------------------------------------------------------------------------
-- WhatRepRecipes - View vendor sell values for all crafted items and reputation requirements, source, price and mats for all unskilled recipe ranks
----------------------------------------------------------------------------------------------------------------------------------------------------
-- Modules/Options.lua - Addon Options
--
-- Author: Expelliarm5s / October 2020 / All Rights Reserved
--
-- Version 1.2.4
-------------------------------------------------------------------------------------------------------
-- luacheck: ignore 212 globals DLAPI

local addonName, addon = ...
local Options = addon:NewModule("Options", "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
--------------------------------------------------------------------------------------------------------

------------------------------------------------------------------------------
-- Settings

Options.defaults = {
	profile = {
	},
	global = {
		timeFormat = "default",
		maxVerbosity = "6",
		showExport = true,
		discardCopper = false,
		discardSilver = false,
		vendorSellSort = true,
		autoList = true,
		textSize = "12",
		isExp = false,
	},
}

Options.timeFormat = {}
Options.timeFormat["ago"]  = L["_ Hr. _ Min. ago"]
Options.timeFormat["%d.%m %H:%M:%S"] = "DD.MM HH:MM"
Options.timeFormat["%m/%d %H:%M:%S"] = "MM/DD HH:MM"
Options.timeFormat["%m-%d %H:%M:%S"] = "MM-DD HH:MM"

Options.textSizes = {}
Options.textSizes["10"]  = "10"
Options.textSizes["11"]  = "11"
Options.textSizes["12"]  = "12"
Options.textSizes["13"]  = "13"

------------------------------------------------------------------------------
-- Debug Stuff

function Options:DebugPrintf(...)
	if addon.isDebug then
		local status, res = pcall(format, ...)
		if status then
			addon:DebugLog("Options~" .. res)
		end
	end
end

------------------------------------------------------------------------------
-- Addon Loading / Player Login/Logout

function Options.GetOptions(uiType, uiName, appName)
	if appName == addonName then

		local wowV, wowP = GetBuildInfo()
		local wowVersion = "|nGame: WoW, Flavor: " .. (addon.isClassic and "Classic" or "Retail") .. ", Version: " .. wowV .. ", Build: " .. wowP

		local options = {
			type = "group",
			name = addon.METADATA.NAME .. " (" .. addon.METADATA.VERSION .. ")",
			get = function(info)
					return addon.db.global[info[#info]] or ""
				end,
			set = function(info, value)
					addon.db.global[info[#info]] = value
					if addon.GUI.display then
						addon.GUI.container:Reload()
					end
				end,
			args = {
				desc1a = {
					type = "description",
					order = 0,
					name = "|cff99ccff-: by " .. GetAddOnMetadata(addonName, "Author") .. " :-|r|n|n" .. GetAddOnMetadata(addonName, "Notes"),
					fontSize = "medium",
				},
				desc1b = {
					type = "description",
					order = 0.01,
					name = wowVersion,
				},
				header04 = {
					type = "header",
					name = L["Recipe List"],
					order = 4.00,
				},
				--timeFormat = {
				--	type = "select",
				--	style = "dropdown",
				--	name = L["Time Format"],
				--	desc = L["Select the format to display times."],
				--	order = 4.01,
				--	width = "normal",
				--	values = Options.timeFormat,
				--},
				--maxVerbosity = {
				--	type = "input",
				--	name = L["Max. Verbosity Level"],
				--	desc = L["Select the maximum verbosity level to show up in the log. Values: 1 to 9. Default: 6."],
				--	order = 4.02,
				--	width = "normal",
				--	validate = function(info, value)
				--		if tonumber(value) and tonumber(value) >= 1 and tonumber(value) <= 9 then
				--			addon.db.global[info[#info]] = value
				--			return true
				--		end
				--		return false
				--	end,
				--},
				--showExport = {
				--	type = "toggle",
				--	name = "Show Search/Export",
				--	desc = "If checked, search and export is always displayed, regardless of the lack of categories/verbosity.",
				--	order = 4.03,
				--	width = "double",
				--	get = function(info) return addon.db.global[info[#info]] end,
				--},
				autoList = {
					type = "toggle",
					name = L["Open Recipes List with Trade Skill Window"],
					desc = L["If checked, recipe list is shown with the Trade Skill Window, otherwise use the WRR button."],
					order = 6.01,
					width = "double",
					get = function(info) return addon.db.global[info[#info]] end,
				},
				vendorSellSort = {
					type = "toggle",
					name = L["Sort by VendorSell"],
					desc = L["If checked, table is sorted by VendorSell."],
					order = 6.02,
					width = "double",
					get = function(info) return addon.db.global[info[#info]] end,
					set = function(info, value)
						addon.db.global[info[#info]] = value
						if value then
							addon.GUI.debugLog_defaultSortTitle = -10
						else
							addon.GUI.debugLog_defaultSortTitle = 1
						end
						if addon.GUI.display then
							addon.GUI.container:Reload()
						end
					end
				},
				discardSilver = {
					type = "toggle",
					name = L["Discard Silver"],
					desc = L["If checked, any values below 1g are not displayed."],
					order = 6.03,
					width = "double",
					get = function(info) return addon.db.global[info[#info]] end,
				},
				discardCopper = {
					type = "toggle",
					name = L["Discard Copper"],
					desc = L["If checked, any values below 1s are not displayed."],
					order = 6.04,
					width = "double",
					get = function(info) return addon.db.global[info[#info]] end,
				},
				textSize = {
					type = "select",
					style = "dropdown",
					name = L["Font Size"],
					desc = L["Choose the font size. Changing the size causes an user interface reload!"],
					order = 6.05,
					width = "double",
					values = Options.textSizes,
					set = function(info, value)
						addon.db.global[info[#info]] = value
						ReloadUI()
					end
				},
				header07 = {
					type = "header",
					name = L["Misc."],
					order = 7.00,
				},
			},
		}

		return options
	end
end

-- EOF
